aboutsummaryrefslogtreecommitdiffstats
path: root/crypto/bn/asm
diff options
context:
space:
mode:
authorBen Laurie <ben@openssl.org>1999-03-27 12:53:21 +0000
committerBen Laurie <ben@openssl.org>1999-03-27 12:53:21 +0000
commit67da3df72e782ebba0bae763e70e42a2c2800899 (patch)
tree5f049718537a85404687938a9bb034c0ab0d1c6f /crypto/bn/asm
parent0e9fc7115b89e672d74fe48f6a2120d8f10d5d97 (diff)
downloadopenssl-67da3df72e782ebba0bae763e70e42a2c2800899.tar.gz
Fix Alpha assembler, remove redundant file.
Diffstat (limited to 'crypto/bn/asm')
-rw-r--r--crypto/bn/asm/alpha.s14
1 files changed, 7 insertions, 7 deletions
diff --git a/crypto/bn/asm/alpha.s b/crypto/bn/asm/alpha.s
index cf0b69cff9..a351694ca2 100644
--- a/crypto/bn/asm/alpha.s
+++ b/crypto/bn/asm/alpha.s
@@ -1,7 +1,7 @@
# DEC Alpha assember
# The bn_div64 is actually gcc output but the other parts are hand done.
# Thanks to tzeruch@ceddec.com for sending me the gcc output for
- # bn_div64.
+ # bn_div_words.
# I've gone back and re-done most of routines.
# The key thing to remeber for the 164 CPU is that while a
# multiply operation takes 8 cycles, another one can only be issued
@@ -328,11 +328,11 @@ $900:
#
.text
.align 3
- .globl bn_div64
- .ent bn_div64
-bn_div64:
+ .globl bn_div_words
+ .ent bn_div_words
+bn_div_words:
ldgp $29,0($27)
-bn_div64..ng:
+bn_div_words..ng:
lda $30,-48($30)
.frame $30,48,$26,0
stq $26,0($30)
@@ -453,7 +453,7 @@ $136:
ldq $13,40($30)
addq $30,48,$30
ret $31,($26),1
- .end bn_div64
+ .end bn_div_words
.set noat
.text
@@ -1,7 +1,7 @@
# DEC Alpha assember
- # The bn_div64 is actually gcc output but the other parts are hand done.
+ # The bn_div_words is actually gcc output but the other parts are hand done.
# Thanks to tzeruch@ceddec.com for sending me the gcc output for